# package_name_cod

Description. 
The package package_name_cod to:
	-Processing:
		- Histogram matching
		- Structural Similarity
		- Resize image

	-Utils:
		- Read Image
		- Save Image
		

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name_cod

```bash
pip install package_name_cod
```

## Usage

```python
from package_name_cod.processamento import combinacao
from package_name_cod.processamento import transformacao
from package_name_cod.utils import io
combinacao.my_function()
transformacao.my_function()
io.my_function()
```

## Author
Codrix

## License
[MIT](https://choosealicense.com/licenses/mit/)